// LICENSE : MIT
"use strict";

/*
 かっこ類と隣接する文字の間のスペースの有無
 かっこの外側、内側ともにスペースを入れません。
 */
var _textlintRuleHelper = require("textlint-rule-helper");
var _matchIndex = require("match-index");
var brackets = ["\\[", "\\]", "（", "）", "［", "］", "「", "」", "『", "』"];
var leftBrackets = brackets.map(bracket => {
  return new RegExp("\([ 　]\)" + bracket, "g");
});
var rightBrackets = brackets.map(bracket => {
  return new RegExp(bracket + "\([ 　])", "g");
});
function reporter(context) {
  var {
    Syntax,
    RuleError,
    report,
    fixer,
    getSource
  } = context;
  var helper = new _textlintRuleHelper.RuleHelper();
  return {
    [Syntax.Str](node) {
      if (!helper.isPlainStrNode(node)) {
        return;
      }
      var text = getSource(node);
      // 左にスペース
      leftBrackets.forEach(pattern => {
        (0, _matchIndex.matchCaptureGroupAll)(text, pattern).forEach(match => {
          var {
            index
          } = match;
          report(node, new RuleError("かっこの外側、内側ともにスペースを入れません。", {
            index: index,
            fix: fixer.replaceTextRange([index, index + 1], "")
          }));
        });
      });
      // 右にスペース
      rightBrackets.forEach(pattern => {
        (0, _matchIndex.matchCaptureGroupAll)(text, pattern).forEach(match => {
          var {
            index,
            text
          } = match;
          report(node, new RuleError("かっこの外側、内側ともにスペースを入れません。", {
            index: index,
            fix: fixer.replaceTextRange([index, index + 1], "")
          }));
        });
      });
    }
  };
}
module.exports = {
  linter: reporter,
  fixer: reporter
};
//# sourceMappingURL=index.js.map